@@ -1,5 +1,7 @@
 import logging
 from abc import abstractmethod
+from datetime import datetime, timedelta
+from typing import Optional
 
 from byteplus.common.protocol import *
 from byteplus.common.url import CommonURL
@@ -31,6 +33,27 @@ class CommonClient(URLCenter):
     def release(self):
         self._host_availabler.shutdown()
 
+    def done(self, date_list: Optional[list], topic: str, *opts: Option) -> DoneResponse:
+        doneDates = []
+        for date in date_list:
+            self.append_done_date(doneDates, date)
+        request: DoneRequest = DoneRequest()
+        request.data_dates.extend(doneDates)
+        url_format = self._common_url.done_url_format
+        url = url_format.replace("#", topic)
+        response = DoneResponse()
+        self._http_caller.do_pb_request(url, request, response, *opts)
+        log.debug("[ByteplusSDK][Done] rsp:\n%s", response)
+        return response
+
+    @staticmethod
+    def append_done_date(doneDates: list, date: datetime):
+        protoDate: Date = Date()
+        protoDate.year = date.year
+        protoDate.month = date.month
+        protoDate.day = date.day
+        doneDates.append(protoDate)
+
     def get_operation(self, request: GetOperationRequest, *opts: Option) -> OperationResponse:
         url: str = self._common_url.get_operation_url
         response: OperationResponse = OperationResponse()
@@ -44,11 +67,3 @@ class CommonClient(URLCenter):
         self._http_caller.do_pb_request(url, request, response, *opts)
         log.debug("[ByteplusSDK][ListOperations] rsp:\n%s", response)
         return response
-
-    def done(self, request: DoneRequest, topic: str, *opts: Option) -> Response:
-        url_format: str = self._common_url.done_url_format
-        url: str = url_format.replace("#", topic)
-        response: Response = Response()
-        self._http_caller.do_pb_request(url, request, response, *opts)
-        log.debug("[ByteplusSDK][Done] rsp:\n%s", response)
-        return response
