@@ -1,4 +1,4 @@
-MAX_WRITE_ITEM_COUNT: int = 100
+MAX_WRITE_ITEM_COUNT: int = 2000
 
 MAX_IMPORT_ITEM_COUNT: int = 10000
 
@@ -10,6 +10,8 @@ _US_HOSTS: list = ["rec-us-east-1.byteplusapi.com"]
 
 _AIR_HOSTS: list = ["byteair-api-cn1.snssdk.com"]
 
+_SAAS_SG_HOSTS: list = ["byteair-api-sg1.recplusapi.com"]
+
 # All requests will have a XXXResponse corresponding to them,
 # and a‘ll XXXResponses will contain a 'Status' field.
 # The status of this request can be determined by the value of `Status.Code`
@@ -23,3 +25,5 @@ STATUS_CODE_IDEMPOTENT: int = 409
 STATUS_CODE_OPERATION_LOSS: int = 410
 # The server hope slow down request frequency, and this request was rejected
 STATUS_CODE_TOO_MANY_REQUEST: int = 429
+
+VOLC_AUTH_SERVICE = "air"
\ No newline at end of file
