@@ -1,17 +1,17 @@
 import datetime
 from abc import abstractmethod
 
-from byteplus.core.options import _Options
+from byteplus.core.options import Options
 
 
 class Option(object):
     @abstractmethod
-    def fill(self, options: _Options) -> None:
+    def fill(self, options: Options) -> None:
         raise NotImplementedError
 
     @staticmethod
-    def conv_to_options(opts: tuple) -> _Options:
-        options: _Options = _Options()
+    def conv_to_options(opts: tuple) -> Options:
+        options: Options = Options()
         for opt in opts:
             opt.fill(options)
         return options
@@ -19,7 +19,7 @@ class Option(object):
     @staticmethod
     def with_timeout(timeout: datetime.timedelta):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.timeout = timeout
 
         return OptionImpl()
@@ -27,7 +27,7 @@ class Option(object):
     @staticmethod
     def with_request_id(request_id: str):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.request_id = request_id
 
         return OptionImpl()
@@ -35,15 +35,15 @@ class Option(object):
     @staticmethod
     def with_headers(headers: dict):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.headers = headers
 
         return OptionImpl()
 
     @staticmethod
-    def with_data_date(date: datetime):
+    def with_data_date(date: datetime.datetime):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.data_date = date
 
         return OptionImpl()
@@ -51,7 +51,7 @@ class Option(object):
     @staticmethod
     def with_data_end(end: bool):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.date_end = end
 
         return OptionImpl()
@@ -59,7 +59,7 @@ class Option(object):
     @staticmethod
     def with_server_timeout(timeout: datetime.timedelta):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.server_timeout = timeout
 
         return OptionImpl()
@@ -67,7 +67,7 @@ class Option(object):
     @staticmethod
     def with_queries(queries: dict):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.queries = queries
 
         return OptionImpl()
@@ -75,7 +75,15 @@ class Option(object):
     @staticmethod
     def with_stage(stage: str):
         class OptionImpl(Option):
-            def fill(self, options: _Options) -> None:
+            def fill(self, options: Options) -> None:
                 options.stage = stage
 
         return OptionImpl()
+
+    @staticmethod
+    def with_scene(scene: str):
+        class OptionImpl(Option):
+            def fill(self, options: Options) -> None:
+                options.scene = scene
+
+        return OptionImpl()
\ No newline at end of file
