@@ -1,5 +1,5 @@
 from datetime import datetime
-from datetime import timedelta
+
 import logging
 from optparse import Option
 from typing import Optional
@@ -7,7 +7,7 @@ from typing import Optional
 from byteplus.common.client import CommonClient
 from byteplus.common.protocol import *
 from byteplus.core import BizException
-from byteplus.core import MAX_WRITE_ITEM_COUNT, MAX_IMPORT_ITEM_COUNT
+from byteplus.core import MAX_IMPORT_ITEM_COUNT
 from byteplus.core import Region
 from byteplus.core.context import Param
 from byteplus.general.url import _GeneralURL
@@ -28,10 +28,8 @@ class Client(CommonClient):
         self._general_url.refresh(host)
 
     def write_data(self, data_list: list, topic: str, *opts: Option) -> WriteResponse:
-        if len(data_list) > MAX_WRITE_ITEM_COUNT:
-            log.warning("[ByteplusSDK][WriteData] item count more than '%d'", MAX_WRITE_ITEM_COUNT)
-            if len(data_list) > MAX_IMPORT_ITEM_COUNT:
-                raise BizException(_ERR_MSG_TOO_MANY_ITEMS)
+        if len(data_list) > MAX_IMPORT_ITEM_COUNT:
+            raise BizException(_ERR_MSG_TOO_MANY_ITEMS)
         url_format: str = self._general_url.write_data_url_format
         url: str = url_format.replace("#", topic)
         response: WriteResponse = WriteResponse()
@@ -39,39 +37,6 @@ class Client(CommonClient):
         log.debug("[ByteplusSDK][WriteData] rsp:\n %s", response)
         return response
 
-    def import_data(self, data_list: Optional[list], topic: str, *opts: Option) -> OperationResponse:
-        if data_list is None:
-            data_list = []
-        if len(data_list) > MAX_IMPORT_ITEM_COUNT:
-            raise BizException(_ERR_MSG_TOO_MANY_ITEMS)
-        url_format: str = self._general_url.import_data_url_format
-        url: str = url_format.replace("#", topic)
-        response: OperationResponse = OperationResponse()
-        self._http_caller.do_json_request(url, data_list, response, *opts)
-        log.debug("[ByteplusSDK][ImportData] rsp:\n%s", response)
-        return response
-
-    def done(self, date_list: Optional[list], topic: str, *opts: Option) -> DoneResponse:
-        date_map_list: list = []
-        if date_list is None or len(date_list) == 0:
-            previous_day = datetime.now() - timedelta(days=1)
-            self.append_done_date(date_map_list, previous_day)
-        else:
-            for date in date_list:
-                self.append_done_date(date_map_list, date)
-        url_format = self._general_url.done_url_format
-        url = url_format.replace("#", topic)
-        response = DoneResponse()
-        self._http_caller.do_json_request(url, date_map_list, response, *opts)
-        log.debug("[ByteplusSDK][Done] rsp:\n%s", response)
-        return response
-
-    @staticmethod
-    def append_done_date(date_map_list: list, date: datetime):
-        formatted_date: str = date.strftime("%Y%m%d")
-        date_map: dict = {"partition_date": formatted_date}
-        date_map_list.append(date_map)
-
     def predict(self, request: PredictRequest, scene: str, *opts: Option) -> PredictResponse:
         url_format: str = self._general_url.predict_url_format
         url: str = url_format.replace("#", scene)
@@ -121,4 +86,5 @@ class ClientBuilder(object):
         return self
 
     def build(self) -> Client:
+        self._param.use_air_auth = True
         return Client(self._param)
